rm(list=ls())


list.of.packages <- c("haven", "stargazer", "readstata13","readr"
                      ,"plyr","dplyr","ggplot2","gghighlight","plm", "lmtest","multiwaycov","broom","tidyr",
                      "interplot","PanelMatch", "lmtest","sandwich","TwoWayFEWeights","DIDmultiplegt","Plotrix","Sampling", "Assertthat", "xtable", "did2s","sandwich")
new.packages <- list.of.packages[!(list.of.packages %in% installed.packages()[,"Package"])]
if(length(new.packages)) install.packages(new.packages)

library(haven)
library(stargazer)
library(readstata13)
library(readr)
library(dplyr)
library(ggplot2)
library(gghighlight)
library(plm)
library(lmtest)
library(multiwayvcov)
library(broom)
library(tidyr)
library(sandwich)
# library(interplot)


final_panel <- read_dta("final_panel.dta")
final_panel <- as.data.frame(final_panel)



# Robust Standard Errors --------------------------------------------------
# This function will be used to obtain robust standard erros

robustse.f <- function(model, cluster, df_correction) {
     ## Huber-White heteroskedasticity-robust standard error calculation and table generation code for lm and glm models in R.
     ##Written by Joshua Gubler ~  http://joshuagubler.com.  Note that the second half of this function is just a wrapper for the excellent "multiwaycov" package here: https://cran.r-project.org/web/packages/multiwayvcov/multiwayvcov.pdf .  Love the authors of that package...
     ##Last updated: 3 July 2017  
     
     #model = the model you estimated, now calculated with robust standard errors
     #cluster = the name of the variable on which you will cluster. Put a tilda in front of it (e.g. ~ state).  If you don't put in a cluster, you will simply get huber-white robust errors.
     #df_correction: If you do not want the number of levels in your cluster variable to count against your degrees of freedom (like the xt- options in Stata), then type "F".  Otherwise, type "T" and these levels will be counted against your degrees of freedom
     
     require(sandwich)
     require(lmtest)
     require(multiwayvcov)
     if(missing(cluster)) {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          model$se <- coeftest(model, vcov=vcovHC(model,"HC1"))[,2]
          model$vcovHC <- vcovHC(model,"HC1")
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcov=vcovHC(model,"HC1"))
     } else {
          name <- deparse(substitute(model))
          modelname <- paste(name,"rob",sep=".")
          vcovCL <- cluster.vcov(model, cluster, df_correction = df_correction)
          model$vcovCL <- vcovCL
          modelname <- paste(name,"clustrob",sep=".")
          model$se <- coeftest(model, vcovCL)[,2]
          assign(modelname,model,envir = .GlobalEnv)
          coeftest(model, vcovCL)
     }
}

# Table 3 Canonical DiD ---------------------------------------------------------------


final_panel <- read_dta("final_panel.dta")
final_panel <- as.data.frame(final_panel)

final_panel <- final_panel %>%
     mutate(time_period = row_number())

remove_states <- read_dta("final_panel.dta")
remove_states <- as.data.frame(remove_states)


remove_states <- remove_states %>% filter(state_name!="Andhra_Pradesh")
remove_states <- remove_states %>% filter(state_name!="Karnataka")
remove_states <- remove_states %>% filter(state_name!="Bihar")
remove_states <- remove_states %>% filter(state_name!="Assam")
remove_states <- remove_states %>% filter(state_name!="Delhi")
remove_states <- remove_states %>% filter(state_name!="Goa")
remove_states <- remove_states %>%
     mutate(time_period = row_number())

m1 <- lm(sex_prop ~ reservation, data = final_panel)
robustse.f(m1, ~assembly_no, F)

m2 <- lm(sex_prop ~ reservation  + factor(state_name) + factor(year_1), data = final_panel)
robustse.f(m2, ~assembly_no, F)



m3 <- lm(sex_prop ~ reservation  + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
              imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3 +
              factor(state_name)+ factor(year_1), data = final_panel)
robustse.f(m3, ~assembly_no, F)


m4_trends <- lm(sex_prop ~ reservation + state_name:time_period +  factor(state_name) + factor(year_1), data = remove_states)
robustse.f(m4_trends, ~state_name, F)



stargazer(m1,m2,m3,m4_trends, omit = "factor", 
          digits=3,
          se=list(m1.clustrob$se,m2.clustrob$se,m3.clustrob$se, m4_trends.clustrob$se),
          title = "Baseline Regression Results",
          type = 'latex',
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          signif.stars = TRUE ,
          add.lines = list(
               c("State Fixed Effect", "No", "Yes", "Yes","Yes"),
               c("Time Fixed Effect", "No", "Yes", "Yes", "Yes"),
               c("State-specific Time Trends", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))


# Table 4 Differing levels---------------------------------------------------------------

fit_m1 <- lm(sex_prop ~ fiftypercent, data = final_panel)
robustse.f(fit_m1, ~assembly_no, F)

fit_m2 <- lm(sex_prop ~ fiftypercent  + factor(year_1) +factor(year_1),  data = final_panel)
robustse.f(fit_m2, ~assembly_no, F)

fit_m4 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology  +
                  i_sexratio + factor(state_name)+ factor(year_1), data = final_panel)
robustse.f(fit_m4, ~assembly_no, F)


fit_m5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3 
             + factor(state_name) + factor(year_1), data = final_panel)
robustse.f(fit_m5, ~assembly_no, F)


stargazer(fit_m1,fit_m2,fit_m4,fit_m5, omit = "factor", 
          digits=3, 
          se=list(fit_m1.clustrob$se,fit_m2.clustrob$se,fit_m4.clustrob$se,fit_m5.clustrob$se),
          type = 'text',
          title = "Regression results showing effects of difffering levels of Quotas",
          covariate.labels = c("fiftypercent", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))



# Table 5 Exposure --------------------------------------------------------

cumulative_1 <- lm(sex_prop ~ five_years + ten_years + fifteen_years + twenty_years , data = final_panel)
robustse.f(cumulative_1, ~assembly_no, F)

cumulative_2 <- lm(sex_prop ~ five_years + ten_years + fifteen_years + twenty_years 
                   + factor(state_name) + factor(year_1), data = final_panel)
robustse.f(cumulative_2, ~assembly_no, F)

stargazer(cumulative_1, cumulative_2 ,omit = "factor",
          digits=3, type="text",
          se=list(cumulative_1.clustrob$se,cumulative_2.clustrob$se),
          add.lines = list(c("Fixed effects?", "No", "Yes"),
                           c("State Level Controls?", "No", "No")),
          title = "Effects of Exposure to Reservation",
          t.auto = TRUE,
          dep.var.labels   = "Proportion of women in all state assemblies",
          notes=c("Robust standard errors in parentheses"))




# Table A.6 Alternative Clustering

m1 <- lm(sex_prop ~ reservation, data = final_panel)
robustse.f(m1, ~state_name, F)
m2 <- lm(sex_prop ~ reservation  + factor(state_name) + factor(year_1), data = final_panel)
robustse.f(m2, ~state_name, F)
m4 <- lm(sex_prop ~ reservation  + nSeats + legIdeology +
              i_sexratio +
              factor(state_name)+ factor(year_1), data = final_panel)
     robustse.f(m4, ~state_name, F)
m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
              imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
         + factor(year_1), data = final_panel)
robustse.f(m5, ~state_name, F)

stargazer(m1,m2,m4,m5, omit = "factor", 
          digits=3,
          se=list(m1.clustrob$se,m2.clustrob$se,m4.clustrob$se,m5.clustrob$se),
          title = "Baseline Regression Results",
          t.auto = TRUE,
          type = 'text',
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                              "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))







# Table A.7 --------------------------------------------

fit_m1 <- lm(sex_prop ~ fiftypercent, data = final_panel)
robustse.f(fit_m1, ~state_name, F)

fit_m2 <- lm(sex_prop ~ fiftypercent  + factor(year_1) +factor(year_1),  data = final_panel)
robustse.f(fit_m2, ~state_name, F)

fit_m4 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology  +
               i_sexratio + factor(state_name)+ factor(year_1), data = final_panel)
robustse.f(fit_m4, ~state_name, F)


fit_m5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
               imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3 
             + factor(state_name) + factor(year_1), data = final_panel)
robustse.f(fit_m5, ~state_name, F)





stargazer(fit_m1,fit_m2,fit_m4,fit_m5, omit = "factor", 
          digits=3, 
          se=list(fit_m1.clustrob$se,fit_m2.clustrob$se,fit_m4.clustrob$se,fit_m5.clustrob$se),
          type = 'text',
          title = "Regression results showing effects of difffering levels of Quotas (alternate clustering)",
          covariate.labels = c("fiftypercent", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))



# Table A.8 on Sub-Sample Here --------------------------------------------
sub <- na.omit(final_panel)

sub_m1 <- lm(sex_prop ~ reservation, data = sub)
robustse.f(sub_m1, ~assembly_no, F)

sub_m2 <- lm(sex_prop ~ reservation  + factor(state_name) + factor(year_1), data = sub)
robustse.f(sub_m2, ~assembly_no, F)
sub_m4 <- lm(sex_prop ~ reservation  + nSeats + legIdeology +
           i_sexratio +
           factor(state_name)+ factor(year_1), data = sub)
robustse.f(sub_m4, ~assembly_no, F)
sub_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
           imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
         + factor(year_1), data = sub)
robustse.f(sub_m5, ~assembly_no, F)


stargazer(sub_m1,sub_m2,sub_m4,sub_m5, omit = "factor", 
          digits=3,
          se=list(sub_m1.clustrob$se,sub_m2.clustrob$se,sub_m4.clustrob$se,sub_m5.clustrob$se),
          title = "Baseline Regression Results",
          t.auto = TRUE,
          type = 'text',
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))

# Table A.9 on Sub-Sample Here --------------------------------------------
sub <- na.omit(final_panel)

fit_m1 <- lm(sex_prop ~ fiftypercent, data = sub)
robustse.f(fit_m1, ~assembly_no, F)

fit_m2 <- lm(sex_prop ~ fiftypercent  + factor(year_1) +factor(year_1),  data = sub)
robustse.f(fit_m2, ~assembly_no, F)

fit_m4 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology  +
               i_sexratio + factor(state_name)+ factor(year_1), data = sub)
robustse.f(fit_m4, ~assembly_no, F)


fit_m5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
               imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3 
             + factor(state_name) + factor(year_1), data = sub)
robustse.f(fit_m5, ~assembly_no, F)

stargazer(fit_m1,fit_m2,fit_m4,fit_m5, omit = "factor", 
          digits=3, 
          se=list(fit_m1.clustrob$se,fit_m2.clustrob$se,fit_m4.clustrob$se,fit_m5.clustrob$se),
          type = 'text',
          title = "Regression results showing effects of difffering levels of Quotas",
          covariate.labels = c("fiftypercent", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))



# Table A.10 Remove Early and Late Adapters -------------------------------------

remove_states <- final_panel

remove_states <- remove_states %>% filter(state_name!="Andhra_Pradesh")
remove_states <- remove_states %>% filter(state_name!="Karnataka")
remove_states <- remove_states %>% filter(state_name!="Bihar")
remove_states <- remove_states %>% filter(state_name!="Assam")
remove_states <- remove_states %>% filter(state_name!="Delhi")


removed_m1 <- lm(sex_prop ~ reservation, data = remove_states)
robustse.f(removed_m1, ~assembly_no, F)

removed_m2 <- lm(sex_prop ~ reservation  + factor(state_name) + factor(year_1), data = remove_states)
robustse.f(removed_m2, ~assembly_no, F)

removed_m4 <- lm(sex_prop ~ reservation  + nSeats + legIdeology +
                   i_sexratio +
                   factor(state_name)+ factor(year_1), data = remove_states)
robustse.f(removed_m4, ~assembly_no, F)

removed_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                   imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
                 + factor(year_1), data = remove_states)
robustse.f(removed_m5, ~assembly_no, F)


stargazer(removed_m1,removed_m2,removed_m4,removed_m5, omit = "factor", 
          digits=3,
          se=list(removed_m1.clustrob$se,removed_m2.clustrob$se,removed_m4.clustrob$se,removed_m5.clustrob$se),
          title = "Results - Excluding All Early and Late Adopters",
          t.auto = TRUE,
          type= 'text',
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "No", "Yes", "Yes", "Yes"),
                           c("State Level Controls?", "No", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))


# Table A.11 Excluding Particular States Robustness ----------------------------------


excludeassam <- final_panel %>% filter(state_name!="Assam")
excludeassam <- na.omit(excludeassam)

excludeKarnataka <- final_panel %>% filter(state_name!="Karnataka")
excludeKarnataka <- na.omit(excludeKarnataka)
excludeAndhra <- final_panel %>% filter(state_name!="Andhra_Pradesh")
excludeAndhra <- na.omit(excludeAndhra)
excludeKarAndhra  <-  final_panel %>% filter(state_name!="Andhra_Pradesh"| state_name!="Karnataka")
excludeBihar <- final_panel %>% filter(state_name!="Bihar")
excludeBihar <- na.omit(excludeBihar)
excludeNE <- final_panel %>% filter(state_name!="Meghalaya"&state_name!="Mizoram"&state_name!="Nagaland")
excludeNE <- na.omit(excludeNE)
excludeGoa <- final_panel %>% filter(state_name!="Goa")
excludeDelhi <- final_panel %>% filter(state_name!="Delhi")
excludeDelhi <- na.omit(excludeDelhi)



#  Table A. 11 Baseline Excludede Models -----------------------------------------------


assam_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                    factor(year_1) + factor(state_name), data = excludeassam)
robustse.f(assam_m5, ~state_name, F)
stargazer(
     assam_m5,
     se = list(assam_m5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)

karnataka_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                        factor(year_1) + factor(state_name), data = excludeKarnataka)
robustse.f(karnataka_m5, ~state_name, F)

stargazer(
     karnataka_m5,
     se = list(karnataka_m5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


andhra_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                     factor(year_1) + factor(state_name), data = excludeAndhra)
robustse.f(andhra_m5, ~state_name, F)

stargazer(
     andhra_m5,
     se = list(andhra_m5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


excludeBihar_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                           factor(year_1) + factor(state_name), data = excludeBihar)
robustse.f(excludeBihar_m5, ~state_name, F)

stargazer(
     excludeBihar_m5,
     se = list(excludeBihar_m5$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)

excludeDelhi_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                           factor(year_1) + factor(state_name), data = excludeDelhi)

robustse.f(excludeDelhi_m5, ~state_name, F)

stargazer(
     excludeDelhi_m5,
     se = list(excludeDelhi_m5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


excludeNE_m5 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio +
                        factor(year_1) + factor(state_name), data = excludeNE)
robustse.f(excludeNE_m5, ~state_name, F)

stargazer(
     excludeNE_m5,
     se = list(excludeNE_m5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)

# Table A.12 Exclude States Levels of Treatment ---------------------------------------------------

assam_fit5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio 
                 + factor(state_name) + factor(year_1), data = excludeassam)
robustse.f(assam_fit5, ~state_name, F)

stargazer(
     assam_fit5,
     se = list(assam_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)



karnataka_fit5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio +
                     + factor(state_name) + factor(year_1), data = excludeKarnataka)
robustse.f(karnataka_fit5, ~state_name, F)

stargazer(
     karnataka_fit5,
     se = list(karnataka_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


andhra_fit5 <- lm(sex_prop ~ fiftypercent +  nSeats +legIdeology + i_sexratio
                  + factor(state_name) + factor(year_1), data = excludeAndhra)
robustse.f(andhra_fit5, ~state_name, F)

stargazer(
     andhra_fit5,
     se = list(andhra_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


excludeBihar_fit5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology
                        + factor(state_name) + factor(year_1), data = excludeBihar)
robustse.f(excludeBihar_fit5, ~state_name, F)

stargazer(
     excludeBihar_fit5,
     se = list(excludeBihar_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)

excludeDelhi_fit5 <- lm(sex_prop ~ fiftypercent + nSeats +legIdeology + i_sexratio 
                        + factor(state_name) + factor(year_1), data = excludeDelhi)
robustse.f(excludeDelhi_fit5, ~state_name, F)

stargazer(
     excludeDelhi_fit5,
     se = list(excludeDelhi_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


excludeNE_fit5 <- lm(sex_prop ~ fiftypercent +  nSeats +legIdeology + i_sexratio 
                     + factor(state_name) + factor(year_1), data = excludeNE)
robustse.f(excludeNE_fit5, ~state_name, F)

stargazer(
     excludeNE_fit5,
     se = list(excludeNE_fit5.clustrob$se),
     title = "Model with Clustered Robust Standard Errors",
     covariate.labels = c("Reservation", "Number of Seats", "Legislative Ideology",
                          "Sex Ratio", "Year (Factor)", "Assembly Number (Factor)"),
     dep.var.labels = "Proportion of Women in State Assemblies",
     type = "latex"
)


# Matching ----------------------------------------------------------------
rm(list=ls())

final_panel <- read_dta("final_panel.dta")
final_panel <- as.data.frame(final_panel)
testing <- final_panel
testing$year <- as.numeric(testing$year_1)


library(PanelMatch)

testing <- testing %>%                              # Create numbering variable
     dplyr::group_by(state_name) %>%
     dplyr::mutate(numbering = row_number())



DisplayTreatment(unit.id = "state_name",
                 time.id = "numbering", legend.position = "none",
                 xlab = "year", ylab = "Country Code",
                 treatment = "reservation", data = as.data.frame(testing))


testing <- testing %>% 
     dplyr:: group_by(state_name) %>% 
     dplyr:: mutate(group_id = cur_group_id())

# testing <- testing %>% dplyr::filter(year_1 >1983)  #To only cover the panel for which I have control variables!

PM.results <- PanelMatch(lag = 3, time.id = "numbering", unit.id = "group_id", 
                         treatment = "reservation", refinement.method = "mahalanobis", 
                         data = as.data.frame(testing), match.missing = T, 
                         covs.formula = ~ sex_prop + nSeats + i_sexratio + legIdeology, 
                         size.match = 2, qoi = "att" ,outcome.var = "sex_prop",
                         lead = 0:4,forbid.treatment.reversal = T)



PE.results <- PanelEstimate(sets = PM.results, data =as.data.frame(testing))


# Gives Figure A.3
plot(PE.results)

rm(list=ls())
library("MatchIt")
library("lmtest") 
library("sandwich") 
library("optmatch")
library("stargazer")


final_panel <- read_dta("final_panel.dta")
final_panel <- as.data.frame(final_panel)

subsample <- final_panel %>% dplyr::filter(year_1 >1983)  #To only cover the panel for which I have control variables! 
subsample=na.omit(subsample)
#Full Match
m.out_full <- matchit(reservation ~ nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                           imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3, 
                      data = subsample, method = "full")

# Gives  Table A.13: Summary of Balance for Matched Data - FullMatch
summary(m.out_full)

     m.data_fullmatch <- match.data(m.out_full)
match_fit1 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio 
                 + factor(state_name) 
                 + factor(year_1), data = m.data_fullmatch, weights = weights)

#Subclassification

m.out_subclass <- matchit(reservation ~ nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                               imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3, 
                          data = subsample, method = "subclass")
# Table A.14: Summary of Balance forMatched Data - SubclassMatch
summary(m.out_subclass)


m.data_subclass <- match.data(m.out_subclass)

match_fit2 <- lm(sex_prop ~ reservation + nSeats +legIdeology + i_sexratio 
                 + factor(state_name) 
                 + factor(year_1), data = m.data_subclass, weights = weights)

# Gives Table A.5
stargazer(match_fit1,match_fit2, omit = "factor", 
          digits=3,
          title = "Matching Regressions",
          t.auto = TRUE,
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes"),
                           c("State Level Controls?",  "Yes", "Yes")))




# A.19 ---------------------------------------------------------------

more_leads <- read_dta("final_panel.dta")
more_leads <- as.data.frame(more_leads)

more_leads <- more_leads %>% 
     group_by(state_name) %>% 
     mutate(
          lead_treat_1 = dplyr::lead(reservation, n = 1, default = 1),
          lead_treat_2 = dplyr::lead(reservation, n = 2, default = 1),
          lead_treat_3 = dplyr::lead(reservation, n = 3, default = 1),
          lead_treat_4 = dplyr::lead(reservation, n = 4, default = 1),
          lead_treat_5 = dplyr::lead(reservation, n = 5, default = 1),
     )



lead_m1 <- lm(sex_prop ~ lead_treat_1 + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
             + factor(year_1), data = more_leads)
robustse.f(lead_m1, ~state_name, F)

lead_m2 <- lm(sex_prop ~ lead_treat_2 + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
             + factor(year_1), data = more_leads)
robustse.f(lead_m2, ~state_name, F)


lead_m3 <- lm(sex_prop ~ lead_treat_3 + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
             + factor(year_1), data = more_leads)
robustse.f(lead_m3, ~state_name, F)


lead_m4 <- lm(sex_prop ~ lead_treat_4 + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
             + factor(year_1), data = more_leads)
robustse.f(lead_m4, ~state_name, F)

lead_m5 <- lm(sex_prop ~ lead_treat_5 + reservation + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
                  imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
             + factor(year_1), data = more_leads)
robustse.f(lead_m5, ~state_name, F)



stargazer(lead_m1,lead_m2,lead_m3,lead_m4,lead_m5, omit = "factor", 
          digits=3,
          se=list(lead_m1.clustrob$se,lead_m2.clustrob$se,lead_m3.clustrob$se,lead_m4.clustrob$se,lead_m5.clustrob$se,lead_m5.clustrob$se),
          title = "Lead Treatment Regression",
          t.auto = TRUE,
          type='text',
          covariate.labels = c("Reservation (lead)", "Reservation (lead2)","Reservation (lead3)","Reservation (lead4)","Reservation (lead5)","Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(c("Fixed effects: State and Time", "Yes", "Yes", "Yes","Yes"),
                           c("State Level Controls?", "Yes", "Yes", "Yes", "Yes")),
          notes=c("Robust standard errors in parentheses"))




# State Specific Trends Table A.20---------------------------------------------------

remove_states <- read_dta("final_panel.dta")
remove_states <- as.data.frame(remove_states)



remove_states <- remove_states %>% filter(state_name!="Andhra_Pradesh")
remove_states <- remove_states %>% filter(state_name!="Karnataka")
remove_states <- remove_states %>% filter(state_name!="Bihar")
remove_states <- remove_states %>% filter(state_name!="Assam")
remove_states <- remove_states %>% filter(state_name!="Delhi")
remove_states <- remove_states %>% filter(state_name!="Goa")




remove_states <- remove_states %>%
     mutate(time_period = row_number())


m1 <- lm(sex_prop ~ reservation + factor(state_name), data = remove_states)
robustse.f(m1, ~state_name, F)

m2 <- lm(sex_prop ~ reservation +  factor(year_1), data = remove_states)
robustse.f(m2, ~state_name, F)

m3 <- lm(sex_prop ~ reservation + state_name:time_period, data = remove_states)
robustse.f(m3, ~state_name, F)




stargazer(m1,m2,m3, omit = "factor", 
          digits=3,
          se=list(m1.clustrob$se,m2.clustrob$se,m3.clustrob$se),
          title = "Baseline Regression Results",
          t.auto = TRUE,
          type = 'latex',
          covariate.labels = c("Reservation"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          add.lines = list(
                           c("State Fixed Effect", "Yes", "No", "No"),
                           c("Time Fixed Effect", "No", "Yes", "No"),
                           c("State-specific Time Trends", "No", "No", "Yes")),
          notes=c("Robust standard errors in parentheses"))






# Sub-sample A. 21---------------------------------------------------------------------

sub_samp2 <- read_dta("final_panel.dta")
sub_samp2 <- as.data.frame(sub_samp2)
sub_samp2 <- na.omit(sub_samp2)

sub_samp2 <- sub_samp2  %>% 
     mutate(time_period = row_number())

m1 <- lm(sex_prop ~ reservation + state_name:time_period, data = sub_samp2)
robustse.f(m1, ~state_name, F)

m2 <- lm(sex_prop ~ reservation + state_name:time_period +  factor(state_name) + factor(year_1), data = sub_samp2)
robustse.f(m2, ~state_name, F)

m5 <- lm(sex_prop ~ reservation + state_name:time_period + nSeats +legIdeology + i_sexratio + i_urban + i_flit + 
              imr + lnsdp + ph3_sh + otrev_pop + ontrev_pop + lnSocExp3  + factor(state_name) 
         + factor(year_1), data = sub_samp2)
robustse.f(m5, ~state_name, F)



stargazer(m1, m2, m5, omit = "factor", 
          digits = 3,
          se=list(m1.clustrob$se, m2.clustrob$se ,m5.clustrob$se),
          title = "Baseline Regression Results",
          t.auto = TRUE,
          type = 'latex',
          covariate.labels = c("Reservation", "Effective Number of Parties in the Govt.", "Legislative Ideology",
                               "Sex Ratio", "Urban Population", "Adult Female Literacy Rate","Infant Mortality", 
                               "Log(State GDP)","Public Health Expenditure as a % of state GDP","State's Tax Revenue", "State's Non-Tax Revenue",
                               "Social Sector Spending"),
          dep.var.labels   = "Proportion of women in all state assemblies",
          notes=c("Robust standard errors in parentheses"))


     


# Event Study -------------------------------------------------------------

# install.packages("did2s")
library(did2s)


event_plot <- final_panel
event_plot <- event_plot %>% select(-(49:26)) %>% 
     select(-c(i_flit,lnsdp,legIdeology,i_sexratio,i_urban,ph3_sh,otrev_pop,ontrev_pop,lnphe3,pcph3_r2,lnSocExp3,imr, nSeats))

event_plot <- event_plot %>%
     group_by(state_name) %>%
     # Create a column for the start of treatment (minimum assembly_no when reservation == 1)
     mutate(start_treatment_year = ifelse(any(reservation == 1), 
                                          min(assembly_no[reservation == 1], na.rm = TRUE), NA)) %>%
     # Calculate 'time_to_treat' based on assembly numbers 
     mutate(time_to_treat = case_when(
          is.na(start_treatment_year) ~ 0,  # If no treatment started, set time_to_treat to 0
          TRUE ~ assembly_no - start_treatment_year  
     )) %>%
     mutate(first_treat = ifelse(any(reservation == 1), 
                                          min(year_1[reservation == 1], na.rm = TRUE), NA)) %>%
     ungroup() %>% 
      filter(time_to_treat > -6)


mod_twfe = feols(sex_prop ~ i(time_to_treat, ref = 0) | 
                      state_name + year_1,                             
                 cluster = ~assembly_no,                                
                 data = event_plot)
summary(mod_twfe)



iplot(mod_twfe, 
      ci_level = 0.95,
      xlab = 'Time to treatment',
      ylab = 'Estimate',
      main = 'Event study: Staggered treatment (TWFE)')

# Step 1: Plot the 95% confidence interval
iplot(mod_twfe, 
      ci_level = 0.95,             # Set CI level to 95%
      xlab = 'Time to treatment',
      ylab = 'Estimate',
      main = 'Event study: Staggered treatment', 
      col = "gray")                # Color for 95% CI


# Step 2: Plot the 90% confidence interval on the same graph
iplot(mod_twfe, 
      ci_level = 0.90,             # Set CI level to 90%
      add = TRUE,                  # Overlay on the previous plot
      col = "red")                 # Color for 90% CI

legend("topleft", 
       legend = c("95% CI", "90% CI"), 
       col = c("gray", "red"), 
       lty = 1)                    # Use solid lines for both



